@@ -23,9 +23,11 @@ extract.psi<-function(lista){
       opz1<-opz
       opz1$it.max <-1
       n<-nrow(mfExt)
-      o0<-try(seg.def.fit(obj, Z, PSI, mfExt, opz), silent=TRUE)
+      o0<-try(suppressWarnings(seg.def.fit(obj, Z, PSI, mfExt, opz)), silent=TRUE)
       rangeZ <- apply(Z, 2, range) #serve sempre
-      
+      alpha <- opz$alpha
+      #limZ <- apply(Z, 2, quantile, names = FALSE, probs = c(alpha, 1 - alpha))
+      limZ <- apply(Z, 2, quantile, names = FALSE, probs = c(alpha[1], alpha[2]))
       if(!is.list(o0)) {
           o0<- seg.def.fit(obj, Z, PSI, mfExt, opz, return.all.sol=TRUE)
           o0<-extract.psi(o0)
@@ -38,9 +40,9 @@ extract.psi<-function(lista){
         } else {
           if(!nonParam) stop("the first fit failed and I cannot extract fitted values for the semipar boot")
           if(random) {
-            est.psi00<-est.psi0<-apply(rangeZ,2,function(r)runif(1,r[1],r[2]))
+            est.psi00<-est.psi0<-apply(limZ,2,function(r)runif(1,r[1],r[2]))
             PSI1 <- matrix(rep(est.psi0, rep(nrow(Z), length(est.psi0))), ncol = length(est.psi0))
-            o0<-try(seg.def.fit(obj, Z, PSI1, mfExt, opz1), silent=TRUE)
+            o0<-try(suppressWarnings(seg.def.fit(obj, Z, PSI1, mfExt, opz1)), silent=TRUE)
             ss00<-o0$SumSquares.no.gap
           } else {
           est.psi00<-est.psi0<-apply(PSI,2,mean)
@@ -73,27 +75,27 @@ extract.psi<-function(lista){
           if(jt) Z<-apply(Z.orig,2,jitter)
           if(nonParam){
               id<-sample(n, size=size.boot, replace=TRUE)
-              o.boot<-try(seg.def.fit(obj, Z[id,,drop=FALSE], PSI[id,,drop=FALSE], mfExt[id,,drop=FALSE], opz.boot), silent=TRUE)
+              o.boot<-try(suppressWarnings(seg.def.fit(obj, Z[id,,drop=FALSE], PSI[id,,drop=FALSE], mfExt[id,,drop=FALSE], opz.boot)), silent=TRUE)
          
           } else {
               yy<-fitted.ok+sample(residuals(o0),size=n, replace=TRUE)
 ##---->              o.boot<-try(seg.lm.fit(yy, XREG, Z.orig, PSI, weights, offs, opz.boot), silent=TRUE)
                     #in realta' la risposta dovrebbe essere "yy" da cambiare in mfExt
-                    o.boot<- try(seg.def.fit(obj, Z.orig, PSI, mfExt, opz.boot), silent=TRUE)
+                    o.boot<- try(suppressWarnings(seg.def.fit(obj, Z.orig, PSI, mfExt, opz.boot)), silent=TRUE)
           }
           if(is.list(o.boot)){
             all.est.psi.boot[k,]<-est.psi.boot<-o.boot$psi
             } else {
-            est.psi.boot<-apply(rangeZ,2,function(r)runif(1,r[1],r[2]))
+            est.psi.boot<-apply(limZ,2,function(r)runif(1,r[1],r[2]))
             }
             PSI <- matrix(rep(est.psi.boot, rep(nrow(Z), length(est.psi.boot))), ncol = length(est.psi.boot))
             opz$h<-max(opz$h*.9, .2)
             opz$it.max<-opz$it.max+1
             o <- try(seg.def.fit(obj, Z.orig, PSI, mfExt, opz, return.all.sol=TRUE), silent=TRUE)
             if(!is.list(o) && random){
-                est.psi0<-apply(rangeZ,2,function(r)runif(1,r[1],r[2]))
+                est.psi0<-apply(limZ,2,function(r)runif(1,r[1],r[2]))
                 PSI1 <- matrix(rep(est.psi0, rep(nrow(Z), length(est.psi0))), ncol = length(est.psi0))
-            o <- try(seg.def.fit(obj, Z, PSI1, mfExt, opz1), silent=TRUE)
+            o <- try(suppressWarnings(seg.def.fit(obj, Z, PSI1, mfExt, opz1)), silent=TRUE)
                 count.random<-count.random+1
               }
             if(is.list(o)){
@@ -129,7 +131,7 @@ extract.psi<-function(lista){
 
       if(is.null(o0$obj)){
           PSI1 <- matrix(rep(est.psi0, rep(nrow(Z), length(est.psi0))), ncol = length(est.psi0))
-            o0 <- try(seg.def.fit(obj, Z, PSI1, mfExt, opz1), silent=TRUE)
+            o0 <- try(suppressWarnings(seg.def.fit(obj, Z, PSI1, mfExt, opz1)), silent=TRUE)
       }
       if(!is.list(o0)) return(0)
       o0$boot.restart<-ris
