@@ -37,8 +37,8 @@ seg.glm.fit<-function(y,XREG,Z,PSI,w,offs,opz,return.all.sol=FALSE){
     #--------------------
     in.psi<-function(LIM, PSI, ret.id=TRUE){
         #check if psi is inside the range
-        a<-PSI[1,]<=LIM[1,]
-        b<-PSI[1,]>=LIM[2,]
+        a<-PSI[1,]<LIM[1,]
+        b<-PSI[1,]>LIM[2,]
         is.ok<- !a & !b #TRUE se psi e' OK
         if(ret.id) return(is.ok)
         isOK<- all(is.ok) && all(!is.na(is.ok))
@@ -81,16 +81,17 @@ seg.glm.fit<-function(y,XREG,Z,PSI,w,offs,opz,return.all.sol=FALSE){
     min.step<-opz$min.step
     rangeZ <- apply(Z, 2, range)
     alpha<-opz$alpha
-    limZ <- apply(Z, 2, quantile, names=FALSE, probs=c(alpha,1-alpha))
+    limZ <- apply(Z, 2, quantile, names=FALSE, probs=c(alpha[1],alpha[2]))
     psi<-PSI[1,]
+    psi<-adj.psi(psi, limZ)
+    PSI<-matrix(psi,nrow=n, ncol=ncol(PSI), byrow=TRUE)
     id.psi.group<-opz$id.psi.group
     conv.psi<-opz$conv.psi 
-    h<-opz$h
     digits<-opz$digits
     pow<-opz$pow
     nomiOK<-opz$nomiOK
     toll<-opz$toll
-    h<-opz$h
+    hh<-opz$h
     gap<-opz$gap
     #fix.npsi<-opz$fix.npsi
     fix.npsi<-opz$stop.if.error
@@ -183,15 +184,17 @@ seg.glm.fit<-function(y,XREG,Z,PSI,w,offs,opz,return.all.sol=FALSE){
         }
         
         psi.old<-psi
-        psi <- psi.old + gamma.c/beta.c
-        #############################aggiusta la stima di psi..
-        #DIREZIONE
+        psi <- psi.old + hh*gamma.c/beta.c
         psi<- adj.psi(psi, rangeZ)
+        #############################aggiusta la stima di psi (nel range.. dopo in limZ)
+        #DIREZIONE
         a<-optimize(search.min, c(0,1), psi=psi, psi.old=psi.old, X=XREG, y=y, w=w, offs=offs) #DUBBIO: Ma fam, eta0, L0 e maxit.glm devo passarli come argom,enti o li trova?
         k.values[length(k.values) + 1] <- use.k <- a$minimum
         L1<- a$objective
         #L1.k[length(L1.k) + 1] <- L1<- a$objective
         psi <- psi*use.k + psi.old* (1-use.k)
+        
+        psi<- adj.psi(psi, limZ)
 
         if(!is.null(digits)) psi<-round(psi, digits)
         PSI <- matrix(rep(psi, rep(n, length(psi))), ncol = length(psi))
